==> mvapich2-2.2rc2.tar.gz: mvapich2-2.2rc2/src/mpi/coll/tuning/allgather/gen2_cma_RI2_28ppn.h <==
#define GEN2_CMA__RI2__28PPN {		\
	{		\
	56,		\
	21,		\
	{		\
	{1, &MPIR_Allgather_RD_MV2},		\
	{2, &MPIR_Allgather_RD_MV2},		\
	{4, &MPIR_Allgather_RD_MV2},		\
	{8, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{16, &MPIR_Allgather_RD_MV2},		\
	{32, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{64, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{128, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{256, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{512, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{1024, &MPIR_Allgather_Ring_MV2},		\
	{2048, &MPIR_Allgather_Ring_MV2},		\
	{4096, &MPIR_Allgather_Ring_MV2},		\
	{8192, &MPIR_Allgather_Ring_MV2},		\
	{16384, &MPIR_Allgather_Ring_MV2},		\
	{32768, &MPIR_Allgather_Ring_MV2},		\
	{65536, &MPIR_Allgather_Ring_MV2},		\
	{131072, &MPIR_Allgather_Ring_MV2},		\
	{262144, &MPIR_Allgather_Ring_MV2},		\
	{524288, &MPIR_Allgather_Ring_MV2},		\
	{1048576, &MPIR_Allgather_Ring_MV2}		\
	}		\
	},		 \
	{		\
	112,		\
	21,		\
	{		\
	{1, &MPIR_Allgather_RD_MV2},		\
	{2, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{4, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{8, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{16, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{32, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{64, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{128, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{256, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{512, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{1024, &MPIR_Allgather_Ring_MV2},		\
	{2048, &MPIR_Allgather_Ring_MV2},		\
	{4096, &MPIR_Allgather_Ring_MV2},		\
	{8192, &MPIR_Allgather_Ring_MV2},		\
	{16384, &MPIR_Allgather_Ring_MV2},		\
	{32768, &MPIR_Allgather_Ring_MV2},		\
	{65536, &MPIR_Allgather_Ring_MV2},		\
	{131072, &MPIR_Allgather_Ring_MV2},		\
	{262144, &MPIR_Allgather_Ring_MV2},		\
	{524288, &MPIR_Allgather_Ring_MV2},		\
	{1048576, &MPIR_Allgather_Ring_MV2}		\
	}		\
	},		 \
	{		\
	224,		\
	21,		\
	{		\
	{1, &MPIR_Allgather_RD_MV2},		\
	{2, &MPIR_Allgather_Bruck_MV2},		\
	{4, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{8, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{16, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{32, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{64, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{128, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{256, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{512, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{1024, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{2048, &MPIR_Allgather_Ring_MV2},		\
	{4096, &MPIR_Allgather_Ring_MV2},		\
	{8192, &MPIR_Allgather_Ring_MV2},		\
	{16384, &MPIR_Allgather_Ring_MV2},		\
	{32768, &MPIR_Allgather_Ring_MV2},		\
	{65536, &MPIR_Allgather_Ring_MV2},		\
	{131072, &MPIR_Allgather_Ring_MV2},		\
	{262144, &MPIR_Allgather_Ring_MV2},		\
	{524288, &MPIR_Allgather_Ring_MV2},		\
	{1048576, &MPIR_Allgather_Ring_MV2}		\
	}		\
	},		 \
	{		\
	448,		\
	21,		\
	{		\
	{1, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{2, &MPIR_Allgather_RD_MV2},		\
	{4, &MPIR_Allgather_RD_MV2},		\
	{8, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{16, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{32, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{64, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{128, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{256, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{512, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{1024, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{2048, &MPIR_Allgather_Ring_MV2},		\
	{4096, &MPIR_Allgather_Ring_MV2},		\
	{8192, &MPIR_Allgather_Ring_MV2},		\
	{16384, &MPIR_Allgather_Ring_MV2},		\
	{32768, &MPIR_Allgather_Ring_MV2},		\
	{65536, &MPIR_Allgather_Ring_MV2},		\
	{131072, &MPIR_Allgather_Ring_MV2},		\
	{262144, &MPIR_Allgather_Ring_MV2},		\
	{524288, &MPIR_Allgather_Ring_MV2},		\
	{1048576, &MPIR_Allgather_Ring_MV2}		\
	}		\
	}		 \
}

==> mvapich2-2.3a.tar.gz: mvapich2-2.3a/src/mpi/coll/tuning/allgather/gen2_cma_RI2_1ppn.h <==
#define GEN2_CMA__RI2__1PPN {		\
	{		\
	2,		\
	21,		\
	{		\
	{1, &MPIR_Allgather_RD_MV2},		\
	{2, &MPIR_Allgather_RD_MV2},		\
	{4, &MPIR_Allgather_Ring_MV2},		\
	{8, &MPIR_Allgather_RD_MV2},		\
	{16, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{32, &MPIR_Allgather_Ring_MV2},		\
	{64, &MPIR_Allgather_RD_MV2},		\
	{128, &MPIR_Allgather_RD_MV2},		\
	{256, &MPIR_Allgather_Ring_MV2},		\
	{512, &MPIR_Allgather_RD_MV2},		\
	{1024, &MPIR_Allgather_RD_MV2},		\
	{2048, &MPIR_Allgather_RD_MV2},		\
	{4096, &MPIR_Allgather_RD_MV2},		\
	{8192, &MPIR_Allgather_RD_MV2},		\
	{16384, &MPIR_Allgather_Ring_MV2},		\
	{32768, &MPIR_Allgather_Ring_MV2},		\
	{65536, &MPIR_Allgather_Ring_MV2},		\
	{131072, &MPIR_Allgather_Ring_MV2},		\
	{262144, &MPIR_Allgather_Ring_MV2},		\
	{524288, &MPIR_Allgather_Ring_MV2},		\
	{1048576, &MPIR_Allgather_Ring_MV2}		\
	}		\
	},		 \
	{		\
	4,		\
	21,		\
	{		\
	{1, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{2, &MPIR_Allgather_RD_MV2},		\
	{4, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{8, &MPIR_Allgather_RD_MV2},		\
	{16, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{32, &MPIR_Allgather_RD_MV2},		\
	{64, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{128, &MPIR_Allgather_Bruck_MV2},		\
	{256, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{512, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{1024, &MPIR_Allgather_RD_MV2},		\
	{2048, &MPIR_Allgather_RD_MV2},		\
	{4096, &MPIR_Allgather_RD_MV2},		\
	{8192, &MPIR_Allgather_RD_MV2},		\
	{16384, &MPIR_Allgather_Ring_MV2},		\
	{32768, &MPIR_Allgather_Ring_MV2},		\
	{65536, &MPIR_Allgather_Ring_MV2},		\
	{131072, &MPIR_Allgather_Ring_MV2},		\
	{262144, &MPIR_Allgather_Ring_MV2},		\
	{524288, &MPIR_Allgather_Ring_MV2},		\
	{1048576, &MPIR_Allgather_Ring_MV2}		\
	}		\
	},		 \
	{		\
	8,		\
	21,		\
	{		\
	{1, &MPIR_Allgather_RD_MV2},		\
	{2, &MPIR_Allgather_RD_MV2},		\
	{4, &MPIR_Allgather_RD_MV2},		\
	{8, &MPIR_Allgather_Bruck_MV2},		\
	{16, &MPIR_Allgather_RD_MV2},		\
	{32, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{64, &MPIR_Allgather_RD_MV2},		\
	{128, &MPIR_Allgather_RD_MV2},		\
	{256, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{512, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{1024, &MPIR_Allgather_RD_MV2},		\
	{2048, &MPIR_Allgather_RD_MV2},		\
	{4096, &MPIR_Allgather_RD_MV2},		\
	{8192, &MPIR_Allgather_RD_MV2},		\
	{16384, &MPIR_Allgather_Ring_MV2},		\
	{32768, &MPIR_Allgather_Ring_MV2},		\
	{65536, &MPIR_Allgather_Ring_MV2},		\
	{131072, &MPIR_Allgather_Ring_MV2},		\
	{262144, &MPIR_Allgather_Ring_MV2},		\
	{524288, &MPIR_Allgather_Ring_MV2},		\
	{1048576, &MPIR_Allgather_Ring_MV2}		\
	}		\
	},		 \
	{		\
	16,		\
	21,		\
	{		\
	{1, &MPIR_Allgather_Bruck_MV2},		\
	{2, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{4, &MPIR_Allgather_RD_MV2},		\
	{8, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{16, &MPIR_Allgather_RD_MV2},		\
	{32, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{64, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{128, &MPIR_Allgather_RD_MV2},		\
	{256, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{512, &MPIR_Allgather_RD_Allgather_Comm_MV2},		\
	{1024, &MPIR_Allgather_RD_MV2},		\
	{2048, &MPIR_Allgather_RD_MV2},		\
	{4096, &MPIR_Allgather_RD_MV2},		\
	{8192, &MPIR_Allgather_RD_MV2},		\
	{16384, &MPIR_Allgather_Ring_MV2},		\
	{32768, &MPIR_Allgather_Ring_MV2},		\
	{65536, &MPIR_Allgather_Ring_MV2},		\
	{131072, &MPIR_Allgather_Ring_MV2},		\
	{262144, &MPIR_Allgather_Ring_MV2},		\
	{524288, &MPIR_Allgather_Ring_MV2},		\
	{1048576, &MPIR_Allgather_Ring_MV2}		\
	}		\
	}		 \
}
